@@ -46,6 +46,6 @@ kmem_free(void *ptr) {
 	free(ptr);
 }
 
-extern void	*kmem_realloc(void *, size_t, int);
+extern void	*krealloc(void *, size_t, int);
 
 #endif
