@@ -239,44 +239,24 @@ xfs_inode_propagate_flags(
 }
 
 /*
- * Allocate an inode on disk and return a copy of its in-core version.
- * Set mode, nlink, and rdev appropriately within the inode.
- * The uid and gid for the inode are set according to the contents of
- * the given cred structure.
- *
- * This was once shared with the kernel, but has diverged to the point
- * where it's no longer worth the hassle of maintaining common code.
+ * Initialise a newly allocated inode and return the in-core inode to the
+ * caller locked exclusively.
  */
 static int
-libxfs_ialloc(
-	xfs_trans_t	*tp,
-	xfs_inode_t	*pip,
-	mode_t		mode,
-	nlink_t		nlink,
-	xfs_dev_t	rdev,
-	struct cred	*cr,
-	struct fsxattr	*fsx,
-	xfs_buf_t	**ialloc_context,
-	xfs_inode_t	**ipp)
+libxfs_init_new_inode(
+	struct xfs_trans	*tp,
+	struct xfs_inode	*pip,
+	xfs_ino_t		ino,
+	umode_t			mode,
+	xfs_nlink_t		nlink,
+	dev_t			rdev,
+	struct cred		*cr,
+	struct fsxattr		*fsx,
+	struct xfs_inode	**ipp)
 {
-	xfs_ino_t	ino;
-	xfs_inode_t	*ip;
-	uint		flags;
-	int		error;
-
-	/*
-	 * Call the space management code to pick
-	 * the on-disk inode to be allocated.
-	 */
-	error = xfs_dialloc(tp, pip ? pip->i_ino : 0, mode,
-			    ialloc_context, &ino);
-	if (error != 0)
-		return error;
-	if (*ialloc_context || ino == NULLFSINO) {
-		*ipp = NULL;
-		return 0;
-	}
-	ASSERT(*ialloc_context == NULL);
+	struct xfs_inode	*ip;
+	unsigned int		flags;
+	int			error;
 
 	error = libxfs_iget(tp->t_mountp, tp, ino, 0, &ip);
 	if (error != 0)
@@ -359,7 +339,7 @@ libxfs_ialloc(
 int
 libxfs_iflush_int(
 	xfs_inode_t			*ip,
-	xfs_buf_t			*bp)
+	struct xfs_buf			*bp)
 {
 	struct xfs_inode_log_item	*iip;
 	xfs_dinode_t			*dip;
@@ -531,53 +511,40 @@ error0:	/* Cancel bmap, cancel trans */
  * other in repair - now there is just the one.
  */
 int
-libxfs_inode_alloc(
-	xfs_trans_t	**tp,
-	xfs_inode_t	*pip,
-	mode_t		mode,
-	nlink_t		nlink,
-	xfs_dev_t	rdev,
-	struct cred	*cr,
-	struct fsxattr	*fsx,
-	xfs_inode_t	**ipp)
+libxfs_dir_ialloc(
+	struct xfs_trans	**tpp,
+	struct xfs_inode	*dp,
+	mode_t			mode,
+	nlink_t			nlink,
+	xfs_dev_t		rdev,
+	struct cred		*cr,
+	struct fsxattr		*fsx,
+	struct xfs_inode	**ipp)
 {
-	xfs_buf_t	*ialloc_context;
-	xfs_inode_t	*ip;
-	int		error;
+	struct xfs_buf		*agibp;
+	xfs_ino_t		parent_ino = dp ? dp->i_ino : 0;
+	xfs_ino_t		ino;
+	int			error;
 
-	ialloc_context = (xfs_buf_t *)0;
-	error = libxfs_ialloc(*tp, pip, mode, nlink, rdev, cr, fsx,
-			   &ialloc_context, &ip);
-	if (error) {
-		*ipp = NULL;
+	/*
+	 * Call the space management code to pick the on-disk inode to be
+	 * allocated.
+	 */
+	error = xfs_dialloc_select_ag(tpp, parent_ino, mode, &agibp);
+	if (error)
 		return error;
-	}
-	if (!ialloc_context && !ip) {
-		*ipp = NULL;
+
+	if (!agibp)
 		return -ENOSPC;
-	}
 
-	if (ialloc_context) {
+	/* Allocate an inode from the selected AG */
+	error = xfs_dialloc_ag(*tpp, agibp, parent_ino, &ino);
+	if (error)
+		return error;
+	ASSERT(ino != NULLFSINO);
 
-		xfs_trans_bhold(*tp, ialloc_context);
-
-		error = xfs_trans_roll(tp);
-		if (error) {
-			fprintf(stderr, _("%s: cannot duplicate transaction: %s\n"),
-				progname, strerror(error));
-			exit(1);
-		}
-		xfs_trans_bjoin(*tp, ialloc_context);
-		error = libxfs_ialloc(*tp, pip, mode, nlink, rdev, cr,
-				   fsx, &ialloc_context, &ip);
-		if (!ip)
-			error = -ENOSPC;
-		if (error)
-			return error;
-	}
-
-	*ipp = ip;
-	return error;
+	return libxfs_init_new_inode(*tpp, dp, ino, mode, nlink, rdev, cr,
+				fsx, ipp);
 }
 
 void
